@@ -8,7 +8,6 @@ Sys::Statistics::Linux - Front-end module to collect system statistics
 
     my $lxs = Sys::Statistics::Linux->new(
         sysinfo   => 1,
-        cpuinfo   => 1,
         cpustats  => 1,
         procstats => 1,
         memstats  => 1,
@@ -294,10 +293,18 @@ How to get processes with the highest cpu workload:
 
 =head1 BACKWARD COMPATIBILITY
 
-The old options and keys - CpuStats, NetStats, etc - are still available but it's not
-possible to access the statistics via C<Sys::Statistics::Linux::Compilation> and it's
+The old options and keys - CpuStats, NetStats, etc - are still available together but deprecated!
+It's not possible to access the statistics via C<Sys::Statistics::Linux::Compilation> and it's
 not possible to call C<search()> and C<psfind()> if you use the old options.
 
+You should use the new options and access the statistics over the accessors
+
+    $stats->cpustats
+
+or direct
+
+    $stats->{cpustats}
+
 =head1 PREREQUISITES
 
     UNIVERSAL
@@ -330,7 +337,7 @@ This program is free software; you can redistribute it and/or modify it under th
 =cut
 
 package Sys::Statistics::Linux;
-our $VERSION = '0.21_02';
+our $VERSION = '0.25_01';
 
 use strict;
 use warnings;
@@ -343,11 +350,10 @@ use Sys::Statistics::Linux::Compilation;
 sub new {
     my $class = shift;
     my @options = qw(
-        SysInfo   CpuInfo   CpuStats
-        ProcStats MemStats  PgSwStats
-        NetStats  SockStats DiskStats
-        DiskUsage LoadAVG   FileStats
-        Processes
+        SysInfo   CpuStats  ProcStats
+        MemStats  PgSwStats NetStats
+        SockStats DiskStats DiskUsage
+        LoadAVG   FileStats Processes
     );
     my $self = bless { obj  => { }, mods => { } }, $class; 
     foreach my $opt (@options) {
